@@ -1,6 +1,6 @@
 ;;; (oauth oauth1 credentials) --- Guile OAuth 1.0 implementation.
 
-;; Copyright (C) 2013-2018 Aleix Conchillo Flaque <aconchillo@gmail.com>
+;; Copyright (C) 2013-2020 Aleix Conchillo Flaque <aconchillo@gmail.com>
 ;;
 ;; This file is part of guile-oauth.
 ;;
@@ -27,27 +27,15 @@
   #:use-module (oauth oauth1 utils)
   #:use-module (rnrs bytevectors)
   #:use-module (srfi srfi-9)
-  #:export (oauth1-credentials
+  #:export (make-oauth1-credentials
             oauth1-credentials?
-            oauth1-credentials-id
-            oauth1-credentials-secret
-            oauth1-token-body->credentials))
+            oauth1-credentials-key
+            oauth1-credentials-secret))
 
 (define-record-type <oauth1-credentials>
-  (oauth1-credentials id secret)
+  (make-oauth1-credentials key secret)
   oauth1-credentials?
-  (id oauth1-credentials-id)
+  (key oauth1-credentials-key)
   (secret oauth1-credentials-secret))
 
-(define (oauth1-token-body->credentials body)
-  "Create a token credentials object with the token identifier and
-secret defined in the given HTTP response @var{body}. The token
-credentials are included using the 'application/x-www-form-urlencoded'
-content type and obtained with the 'oauth_token' and
-'oauth_token_secret' parameters respectively."
-  (let* ((str-body (if (string? body) body (utf8->string body)))
-         (params (oauth1-parse-www-form-urlencoded str-body)))
-    (oauth1-credentials (assoc-ref params "oauth_token")
-                        (assoc-ref params "oauth_token_secret"))))
-
 ;;; (oauth oauth1 credentials) ends here
